lnoise
=====

Python implementation of the [Noise Protocol Framework](https://noiseprotocol.org/) for bitcoin lightning.

Based on [effigies implementation of NPF](https://github.com/effigies/noise).

Dependencies
------------
* [chacha20poly1305](https://github.com/ph4r05/py-chacha20poly1305) for CHACHA20_POLY1305
* [secp256k1-py](https://github.com/ludbb/secp256k1-py) for elliptic cryptography
* standart library for sha256 and hmac
